@@ -1,5 +1,5 @@
 __author__ = 'Alex Rogozhnikov'
-__version__ = '0.5.0'
+__version__ = '0.6.0'
 
 
 class EinopsError(RuntimeError):
@@ -8,6 +8,8 @@ class EinopsError(RuntimeError):
 
 
 __all__ = ['rearrange', 'reduce', 'repeat', 'einsum',
+           'pack', 'unpack',
            'parse_shape', 'asnumpy', 'EinopsError']
 
 from .einops import rearrange, reduce, repeat, einsum, parse_shape, asnumpy
+from .packing import pack, unpack
\ No newline at end of file
