@@ -1,7 +1,7 @@
 import itertools
 
 import numpy
-from nose.tools import assert_raises
+import pytest
 
 from einops import EinopsError
 from einops.einops import (rearrange, reduce, _enumerate_directions, _reductions)
@@ -41,11 +41,11 @@ equivalent_reduction_patterns = [
 def test_collapsed_ellipsis_errors_out():
     x = numpy.zeros([1, 1, 1, 1, 1])
     rearrange(x, 'a b c d ... ->  a b c ... d')
-    with assert_raises(EinopsError):
+    with pytest.raises(EinopsError):
         rearrange(x, 'a b c d (...) ->  a b c ... d')
 
     rearrange(x, '... ->  (...)')
-    with assert_raises(EinopsError):
+    with pytest.raises(EinopsError):
         rearrange(x, '(...) -> (...)')
 
 
@@ -274,7 +274,7 @@ def test_reduction_stress_imperatives():
             if reduction in ['mean', 'prod']:
                 dtype = 'float64'
                 coincide = numpy.allclose
-            for n_axes in range(6 if 'mxnet' in backend.framework_name else 11):
+            for n_axes in range(6 if 'mxnet' in backend.framework_name else (7 if 'oneflow' in backend.framework_name else 11)):
                 shape = numpy.random.randint(2, 4, size=n_axes)
                 permutation = numpy.random.permutation(n_axes)
                 skipped = 0 if reduction == 'rearrange' else numpy.random.randint(n_axes + 1)
